# -*- coding: utf-8 -*-
# Generated by Django 1.11.4 on 2017-11-18 03:26
from __future__ import unicode_literals

import datetime
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('app', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='action',
            name='created_at',
            field=models.DateTimeField(default=datetime.datetime(2017, 11, 18, 3, 26, 17, 805227)),
        ),
        migrations.AlterField(
            model_name='action',
            name='resource',
            field=models.ForeignKey(blank=True, on_delete=django.db.models.deletion.CASCADE, related_name='actions', to='app.Resource'),
        ),
    ]
